@@ -25,7 +25,8 @@
 
 #include "xap_App.h"
 #include "xap_QNXApp.h"
-#include "xap_QNXFrame.h"
+#include "xap_QNXFrameImpl.h"
+#include "xap_Frame.h"
 
 #include "ap_Strings.h"
 #include "ap_Dialog_Id.h"
@@ -155,47 +156,6 @@ static int s_remove_property(PtWidget_t *widget, void *data, PtCallbackInfo_t *i
 	return Pt_CONTINUE;
 }
 
-static int s_style_nadlg(PtWidget_t *widget, void *data, PtCallbackInfo_t *info)
-{
-	AP_QNXDialog_Styles * dlg = (AP_QNXDialog_Styles *)data;
-	UT_ASSERT(widget && dlg);
-	dlg->new_styleName();
-	return Pt_CONTINUE;
-}
-
-
-static int s_basedon(PtWidget_t *widget, void *data, PtCallbackInfo_t *info)
-{
-	AP_QNXDialog_Styles * dlg = (AP_QNXDialog_Styles *)data;
-	UT_ASSERT(widget && dlg);
-	if(dlg->isModifySignalBlocked())
-		return Pt_CONTINUE;
-	dlg->event_basedOn();
-	return Pt_CONTINUE;
-}
-
-
-static int s_followedby(PtWidget_t *widget, void *data, PtCallbackInfo_t *info)
-{
-	AP_QNXDialog_Styles * dlg = (AP_QNXDialog_Styles *)data;
-	UT_ASSERT(widget && dlg);
-	if(dlg->isModifySignalBlocked())
-		return Pt_CONTINUE;
-	dlg->event_followedBy();
-	return Pt_CONTINUE;
-}
-
-
-static int s_styletype(PtWidget_t *widget, void *data, PtCallbackInfo_t *info)
-{
-	AP_QNXDialog_Styles * dlg = (AP_QNXDialog_Styles *)data;
-	UT_ASSERT(widget && dlg);
-	if(dlg->isModifySignalBlocked())
-		return Pt_CONTINUE;
-	dlg->event_styleType();
-	return Pt_CONTINUE;
-}
-
 static int s_apply_clicked(PtWidget_t *widget, void *data, PtCallbackInfo_t *info)
 {
 	AP_QNXDialog_Styles * dlg = (AP_QNXDialog_Styles *)data;
@@ -379,12 +339,10 @@ void AP_QNXDialog_Styles::runModal(XAP_Frame * pFrame)
 	UT_ASSERT(getDoc());
 
 	// To center the dialog, we need the frame of its parent.
-	XAP_QNXFrame * pQNXFrame = static_cast<XAP_QNXFrame *>(pFrame);
-	UT_ASSERT(pQNXFrame);
-	
-	// Get the Window of the parent frame
-	PtWidget_t * parentWindow = pQNXFrame->getTopLevelWindow();
+	XAP_QNXFrameImpl * pQNXFrameImpl = (XAP_QNXFrameImpl*)pFrame->getFrameImpl();
+	PtWidget_t *parentWindow =	pQNXFrameImpl->getTopLevelWindow();	
 	UT_ASSERT(parentWindow);
+
 	PtSetParentWidget(parentWindow);
 
 	// Build the window's widgets and arrange them
@@ -547,9 +505,9 @@ void AP_QNXDialog_Styles::event_ListClicked(const char * which)
 {
 	const XAP_StringSet * pSS = m_pApp->getStringSet();
 
-	if (!strcmp(which, pSS->getValue(AP_STRING_ID_DLG_Styles_LBL_InUse)))
+if (!strcmp(which, pSS->getValueUTF8(AP_STRING_ID_DLG_Styles_LBL_InUse).utf8_str()))
 		m_whichType = USED_STYLES;
-	else if (!strcmp(which, pSS->getValue(AP_STRING_ID_DLG_Styles_LBL_UserDefined)))
+else if (!strcmp(which, pSS->getValueUTF8(AP_STRING_ID_DLG_Styles_LBL_UserDefined).utf8_str()))
 		m_whichType = USER_STYLES;
 	else
 		m_whichType = ALL_STYLES;
@@ -567,13 +525,9 @@ PtWidget_t * AP_QNXDialog_Styles::_constructWindow(void)
 	PtWidget_t * buttonClose;
 
 	PtWidget_t * vgroup, * hgroup;
-	PtWidget_t * vboxTopLeft;
-	PtWidget_t * vboxTopRight;
 
-	PtWidget_t * frameStyles;
 	PtWidget_t *	listStyles;
 
-	PtWidget_t * frameList;
 	PtWidget_t * comboList;
 
 	PtWidget_t * frameParaPrev;
@@ -585,10 +539,6 @@ PtWidget_t * AP_QNXDialog_Styles::_constructWindow(void)
 	PtWidget_t * frameDescription;
 	PtWidget_t * DescriptionArea;
 
-	PtWidget_t * hsepBot;
-
-	PtWidget_t * buttonBoxStyleManip;
-
 	PtWidget_t * buttonNew;
 	PtWidget_t * buttonModify;
 	PtWidget_t * buttonDelete;
@@ -602,10 +552,13 @@ PtWidget_t * AP_QNXDialog_Styles::_constructWindow(void)
 
 	n = 0;
 	PtSetArg(&args[n++], Pt_ARG_WINDOW_TITLE, 
-		pSS->getValue(AP_STRING_ID_DLG_Styles_StylesTitle), 0);
+_(AP,DLG_Styles_StylesTitle), 0);
     PtSetArg(&args[n++], Pt_ARG_WINDOW_RENDER_FLAGS, 0, ABI_MODAL_WINDOW_RENDER_FLAGS);
     PtSetArg(&args[n++], Pt_ARG_WINDOW_MANAGED_FLAGS, 0, ABI_MODAL_WINDOW_MANAGE_FLAGS);
 	windowStyles = PtCreateWidget(PtWindow, NULL, n, args);
+	SetupContextHelp(windowStyles,this);
+	PtAddHotkeyHandler(windowStyles,Pk_F1,0,Pt_HOTKEY_SYM,this,OpenHelp);
+
 	PtAddCallback(windowStyles, Pt_CB_WINDOW_CLOSING, s_delete_clicked, this);
 
 	n = 0;
@@ -624,7 +577,6 @@ PtWidget_t * AP_QNXDialog_Styles::_constructWindow(void)
 	/* Left pane is a list of styles and types */
 	n = 0;
 	hgroup = PtCreateWidget(PtGroup, vgroup, n, args);
-	//frameStyles = gtk_frame_new(pSS->getValue(AP_STRING_ID_DLG_Styles_Available));
 
 	PtWidget_t *top_vgrouplist, *top_vgroupshow;
 
@@ -643,11 +595,10 @@ PtWidget_t * AP_QNXDialog_Styles::_constructWindow(void)
 	n = 0;
 	PtSetArg(&args[n++], Pt_ARG_WIDTH, PREVIEW_WIDTH, 0);
 	comboList = PtCreateWidget(PtComboBox, top_vgrouplist, n, args);
-	//frameList = gtk_frame_new( pSS->getValue(AP_STRING_ID_DLG_Styles_List));
 	const char *items[3];
-	items[0] = pSS->getValue (AP_STRING_ID_DLG_Styles_LBL_InUse);
-	items[1] = pSS->getValue(AP_STRING_ID_DLG_Styles_LBL_All);
-	items[2] = pSS->getValue(AP_STRING_ID_DLG_Styles_LBL_UserDefined);
+	items[0] = pSS->getValueUTF8 (AP_STRING_ID_DLG_Styles_LBL_InUse).utf8_str();
+items[1] = pSS->getValueUTF8(AP_STRING_ID_DLG_Styles_LBL_All).utf8_str();
+items[2] = pSS->getValueUTF8(AP_STRING_ID_DLG_Styles_LBL_UserDefined).utf8_str();
 	PtListAddItems(comboList, items, 3, 0);  
 	UT_QNXComboSetPos(comboList, 1);
 	PtAddCallback(comboList, Pt_CB_SELECTION, s_typeslist_changed, this);
@@ -659,7 +610,7 @@ PtWidget_t * AP_QNXDialog_Styles::_constructWindow(void)
 
 	n = 0;
 	frameParaPrev = PtCreateWidget(PtGroup, top_vgroupshow, n, args);
-	pretty_group(frameParaPrev, pSS->getValue(AP_STRING_ID_DLG_Styles_ParaPrev));
+	pretty_group(frameParaPrev, pSS->getValueUTF8(AP_STRING_ID_DLG_Styles_ParaPrev ).utf8_str());
 	n = 0;
 	PtSetArg(&args[n++], Pt_ARG_WIDTH, PREVIEW_WIDTH, 0);
 	PtSetArg(&args[n++], Pt_ARG_HEIGHT, 70, 0);
@@ -670,7 +621,7 @@ PtWidget_t * AP_QNXDialog_Styles::_constructWindow(void)
 
 	n = 0;
 	frameCharPrev = PtCreateWidget(PtGroup, top_vgroupshow, n, args);
-	pretty_group(frameCharPrev, pSS->getValue(AP_STRING_ID_DLG_Styles_CharPrev));
+	pretty_group(frameCharPrev, pSS->getValueUTF8(AP_STRING_ID_DLG_Styles_CharPrev ).utf8_str());
 	n = 0;
 	PtSetArg(&args[n++], Pt_ARG_WIDTH, PREVIEW_WIDTH, 0);
 	PtSetArg(&args[n++], Pt_ARG_HEIGHT, 50, 0);
@@ -681,37 +632,31 @@ PtWidget_t * AP_QNXDialog_Styles::_constructWindow(void)
 
 	n = 0;
 	frameDescription = PtCreateWidget(PtGroup, top_vgroupshow, n, args);
-	pretty_group(frameDescription, pSS->getValue(AP_STRING_ID_DLG_Styles_Description));
+	pretty_group(frameDescription, pSS->getValueUTF8(AP_STRING_ID_DLG_Styles_Description ).utf8_str());
 	n = 0;
 	PtSetArg(&args[n++], Pt_ARG_WIDTH, PREVIEW_WIDTH, 0);
 	PtSetArg(&args[n++], Pt_ARG_HEIGHT, 60, 0);
 	PtSetArg(&args[n++], Pt_ARG_SCROLLBAR_Y_DISPLAY, Pt_AS_REQUIRED, Pt_AS_REQUIRED);
 	DescriptionArea = PtCreateWidget(PtMultiText, frameDescription, n, args);
 
-	//gtk_label_set_line_wrap (GTK_LABEL(DescriptionArea), TRUE);
-	//gtk_label_set_justify (GTK_LABEL(DescriptionArea), GTK_JUSTIFY_LEFT);
-	//gtk_container_add(GTK_CONTAINER(frameDescription), DescriptionArea);
-	//gtk_misc_set_alignment(GTK_MISC(DescriptionArea), 0, 0);
-	//gtk_misc_set_padding(GTK_MISC(DescriptionArea), 8, 6);
-
 	/* These buttons are above the normal buttons */
 	n = 0;
 	hgroup = PtCreateWidget(PtGroup, vgroup, n, args);
 
 	n = 0;
-	PtSetArg(&args[n++], Pt_ARG_TEXT_STRING, pSS->getValue(AP_STRING_ID_DLG_Styles_New), 0);
+PtSetArg(&args[n++], Pt_ARG_TEXT_STRING, _(AP,DLG_Styles_New), 0);
 	PtSetArg(&args[n++], Pt_ARG_WIDTH, ABI_DEFAULT_BUTTON_WIDTH, 0);
 	buttonNew = PtCreateWidget(PtButton, hgroup, n, args);
 	PtAddCallback(buttonNew, Pt_CB_ACTIVATE, s_newbtn_clicked, this);
 
 	n = 0;
-	PtSetArg(&args[n++], Pt_ARG_TEXT_STRING, pSS->getValue(AP_STRING_ID_DLG_Styles_Modify), 0);
+PtSetArg(&args[n++], Pt_ARG_TEXT_STRING, _(AP,DLG_Styles_Modify), 0);
 	PtSetArg(&args[n++], Pt_ARG_WIDTH, ABI_DEFAULT_BUTTON_WIDTH, 0);
 	buttonModify = PtCreateWidget(PtButton, hgroup, n, args);
 	PtAddCallback(buttonModify, Pt_CB_ACTIVATE, s_modifybtn_clicked, this);
 
 	n = 0;
-	PtSetArg(&args[n++], Pt_ARG_TEXT_STRING, pSS->getValue(AP_STRING_ID_DLG_Styles_Delete), 0);
+PtSetArg(&args[n++], Pt_ARG_TEXT_STRING, _(AP,DLG_Styles_Delete), 0);
 	PtSetArg(&args[n++], Pt_ARG_WIDTH, ABI_DEFAULT_BUTTON_WIDTH, 0);
 	buttonDelete = PtCreateWidget(PtButton, hgroup, n, args);
 	PtAddCallback(buttonDelete, Pt_CB_ACTIVATE, s_deletebtn_clicked, this);
@@ -721,13 +666,13 @@ PtWidget_t * AP_QNXDialog_Styles::_constructWindow(void)
 	hgroup = PtCreateWidget(PtGroup, vgroup, n, args);
 
 	n = 0;
-	PtSetArg(&args[n++], Pt_ARG_TEXT_STRING, pSS->getValue(XAP_STRING_ID_DLG_Close), 0);
+PtSetArg(&args[n++], Pt_ARG_TEXT_STRING, _(XAP,DLG_Close), 0);
 	PtSetArg(&args[n++], Pt_ARG_WIDTH, ABI_DEFAULT_BUTTON_WIDTH, 0);
 	buttonClose = PtCreateWidget(PtButton, hgroup, n, args);
 	PtAddCallback(buttonClose, Pt_CB_ACTIVATE, s_close_clicked, this);
 
 	n = 0;
-	PtSetArg(&args[n++], Pt_ARG_TEXT_STRING, pSS->getValue(XAP_STRING_ID_DLG_Apply), 0);
+PtSetArg(&args[n++], Pt_ARG_TEXT_STRING, _(XAP,DLG_Apply), 0);
 	PtSetArg(&args[n++], Pt_ARG_WIDTH, ABI_DEFAULT_BUTTON_WIDTH, 0);
 	buttonApply = PtCreateWidget(PtButton, hgroup, n, args);
 	PtAddCallback(buttonApply, Pt_CB_ACTIVATE, s_apply_clicked, this);
@@ -795,8 +740,7 @@ void AP_QNXDialog_Styles::setDescription(const char * desc) const
 
 const char * AP_QNXDialog_Styles::getCurrentStyle (void) const
 {
-	static UT_String szStyleBuf;
-	int ret;
+	static UT_UTF8String szStyleBuf;
 	char **items;
 
 	UT_ASSERT(m_wclistStyles);
@@ -813,7 +757,7 @@ const char * AP_QNXDialog_Styles::getCurrentStyle (void) const
 
 	szStyleBuf = items[m_whichRow + 1];
 
-	return szStyleBuf.c_str();
+	return szStyleBuf.utf8_str();
 }
 
 /***
@@ -860,9 +804,6 @@ PtWidget_t *  AP_QNXDialog_Styles::_constructModifyDialog(void)
 	PtWidget_t *windowModify;
 	PtWidget_t *vgroup, *hgroup;
 
-	PtWidget_t *dialog_vbox1 = NULL;
-	PtWidget_t *OverallVbox = NULL;
-	PtWidget_t *comboTable  = NULL;
 	PtWidget_t *nameLabel  = NULL;
 	PtWidget_t *basedOnLabel  = NULL;
 	PtWidget_t *followingLabel = NULL;
@@ -878,9 +819,6 @@ PtWidget_t *  AP_QNXDialog_Styles::_constructModifyDialog(void)
 	PtWidget_t *modifyDrawingArea = NULL;
 	PtWidget_t *descriptionFrame = NULL;
 	PtWidget_t *descriptionText = NULL;
-	PtWidget_t *checkBoxRow = NULL;
-	PtWidget_t *checkAddTo = NULL;
-	PtWidget_t *checkAutoUpdate = NULL;
 	PtWidget_t *deletePropCombo = NULL;
 	PtWidget_t *deletePropEntry = NULL;
 	PtWidget_t *deletePropButton = NULL;
@@ -894,10 +832,10 @@ PtWidget_t *  AP_QNXDialog_Styles::_constructModifyDialog(void)
 	n = 0;
 	if(!isNew()) {
 		PtSetArg(&args[n++], Pt_ARG_WINDOW_TITLE, 
-			pSS->getValue(AP_STRING_ID_DLG_Styles_ModifyTitle), 0);
+_(AP,DLG_Styles_ModifyTitle), 0);
 	} else {
 		PtSetArg(&args[n++], Pt_ARG_WINDOW_TITLE, 
-			pSS->getValue(AP_STRING_ID_DLG_Styles_NewTitle), 0);
+_(AP,DLG_Styles_NewTitle), 0);
 	}
     PtSetArg(&args[n++], Pt_ARG_WINDOW_RENDER_FLAGS, 0, ABI_MODAL_WINDOW_RENDER_FLAGS);
     PtSetArg(&args[n++], Pt_ARG_WINDOW_MANAGED_FLAGS, 0, ABI_MODAL_WINDOW_MANAGE_FLAGS);
@@ -922,11 +860,11 @@ PtWidget_t *  AP_QNXDialog_Styles::_constructModifyDialog(void)
 	hgroup = PtCreateWidget(PtGroup, vgroup, n, args);
 
 	n = 0;
-	PtSetArg(&args[n++], Pt_ARG_TEXT_STRING, pSS->getValue(AP_STRING_ID_DLG_Styles_ModifyName), 0);
+PtSetArg(&args[n++], Pt_ARG_TEXT_STRING, _(AP,DLG_Styles_ModifyName), 0);
 	nameLabel = PtCreateWidget(PtLabel, hgroup, n, args);
 
 	n = 0;
-	PtSetArg(&args[n++], Pt_ARG_TEXT_STRING, pSS->getValue(AP_STRING_ID_DLG_Styles_ModifyType), 0); 
+PtSetArg(&args[n++], Pt_ARG_TEXT_STRING, _(AP,DLG_Styles_ModifyType), 0);
 	styleTypeLabel = PtCreateWidget(PtLabel, hgroup, n, args);
 
 	n = 0;
@@ -941,11 +879,11 @@ PtWidget_t *  AP_QNXDialog_Styles::_constructModifyDialog(void)
 
 
 	n = 0;
-	PtSetArg(&args[n++], Pt_ARG_TEXT_STRING, pSS->getValue(AP_STRING_ID_DLG_Styles_ModifyBasedOn), 0);
+PtSetArg(&args[n++], Pt_ARG_TEXT_STRING, _(AP,DLG_Styles_ModifyBasedOn), 0);
 	basedOnLabel = PtCreateWidget(PtLabel, hgroup, n, args);
 
 	n = 0;
-	PtSetArg(&args[n++], Pt_ARG_TEXT_STRING, pSS->getValue(AP_STRING_ID_DLG_Styles_ModifyFollowing), 0);
+PtSetArg(&args[n++], Pt_ARG_TEXT_STRING, _(AP,DLG_Styles_ModifyFollowing), 0);
 	followingLabel = PtCreateWidget(PtLabel, hgroup, n, args);
 
 	n = 0;
@@ -967,7 +905,7 @@ PtWidget_t *  AP_QNXDialog_Styles::_constructModifyDialog(void)
 	hgroup = PtCreateWidget(PtGroup, vgroup, n, args);
 	n = 0;
 	previewFrame = PtCreateWidget(PtGroup, hgroup, n, args);
-	pretty_group(previewFrame, pSS->getValue(AP_STRING_ID_DLG_Styles_ModifyPreview));
+	pretty_group(previewFrame, _(AP,DLG_Styles_ModifyPreview ));
 	n = 0;
 	PtSetArg(&args[n++], Pt_ARG_WIDTH, PREVIEW_WIDTH, 0);
 	PtSetArg(&args[n++], Pt_ARG_HEIGHT, 120, 0);
@@ -981,7 +919,7 @@ PtWidget_t *  AP_QNXDialog_Styles::_constructModifyDialog(void)
 	hgroup = PtCreateWidget(PtGroup, vgroup, n, args);
 	n = 0;
 	descriptionFrame = PtCreateWidget(PtGroup, hgroup, n, args);
-	pretty_group(descriptionFrame, pSS->getValue(AP_STRING_ID_DLG_Styles_ModifyDescription));
+	pretty_group(descriptionFrame, _(AP,DLG_Styles_ModifyDescription ));
 	n = 0;
 	PtSetArg(&args[n++], Pt_ARG_WIDTH, PREVIEW_WIDTH, 0);
 	PtSetArg(&args[n++], Pt_ARG_HEIGHT, 120, 0);
@@ -992,35 +930,20 @@ PtWidget_t *  AP_QNXDialog_Styles::_constructModifyDialog(void)
 	hgroup = PtCreateWidget(PtGroup, vgroup, n, args);
 
 	n = 0;
-	PtSetArg(&args[n++], Pt_ARG_TEXT_STRING, pSS->getValue(AP_STRING_ID_DLG_Styles_RemoveLab), 0);
-	PtWidget_t * deleteLabel = PtCreateWidget(PtLabel, hgroup, n, args);
+PtSetArg(&args[n++], Pt_ARG_TEXT_STRING, _(AP,DLG_Styles_RemoveLab), 0);
+	PtCreateWidget(PtLabel, hgroup, n, args);
 
 	n = 0;
 	PtSetArg(&args[n++], Pt_ARG_WIDTH, ABI_DEFAULT_BUTTON_WIDTH, 0);
 	deletePropEntry = PtCreateWidget(PtComboBox, hgroup, n, args);
 
 	n = 0;
-	PtSetArg(&args[n++], Pt_ARG_TEXT_STRING, pSS->getValue(AP_STRING_ID_DLG_Styles_RemoveButton), 0);
+PtSetArg(&args[n++], Pt_ARG_TEXT_STRING, _(AP,DLG_Styles_RemoveButton), 0);
 	PtSetArg(&args[n++], Pt_ARG_WIDTH, ABI_DEFAULT_BUTTON_WIDTH, 0);
 	deletePropButton = PtCreateWidget(PtButton, hgroup, n, args);
 	PtAddCallback(deletePropButton, Pt_CB_ACTIVATE, s_remove_property, this);
 
-#if 0
-	checkBoxRow = gtk_hbox_new (FALSE, 3);
-	gtk_box_pack_start (GTK_BOX (OverallVbox), checkBoxRow, TRUE, TRUE, 0);
-	gtk_container_set_border_width (GTK_CONTAINER (checkBoxRow), 2);
-
-	checkAddTo = gtk_check_button_new_with_label (pSS->getValue(AP_STRING_ID_DLG_Styles_ModifyTemplate));
-	gtk_widget_show (checkAddTo);
-	gtk_box_pack_start (GTK_BOX (checkBoxRow), checkAddTo, TRUE, TRUE, 0);
-
-	checkAutoUpdate = gtk_check_button_new_with_label (pSS->getValue(AP_STRING_ID_DLG_Styles_ModifyAutomatic));
-	gtk_widget_show (checkAutoUpdate);
-	gtk_box_pack_start (GTK_BOX (checkBoxRow), checkAutoUpdate, TRUE, TRUE, 0);
-#endif
-
 	/* Add the bottom group of buttons */
-	PtWidget_t *bottomButtons;
 	PtWidget_t *buttonOK;
 	PtWidget_t *buttonCancel;
 	PtWidget_t *FormatMenu;
@@ -1030,13 +953,13 @@ PtWidget_t *  AP_QNXDialog_Styles::_constructModifyDialog(void)
 	hgroup = PtCreateWidget(PtGroup, vgroup, n, args);
 
 	n = 0;
-	PtSetArg(&args[n++], Pt_ARG_TEXT_STRING, pSS->getValue(XAP_STRING_ID_DLG_Cancel), 0);
+PtSetArg(&args[n++], Pt_ARG_TEXT_STRING, _(XAP,DLG_Cancel), 0);
 	PtSetArg(&args[n++], Pt_ARG_WIDTH, ABI_DEFAULT_BUTTON_WIDTH, 0);
 	buttonCancel = PtCreateWidget(PtButton, hgroup, n, args);
 	PtAddCallback(buttonCancel, Pt_CB_ACTIVATE, s_modify_cancel_clicked, this);
 
 	n = 0;
-	PtSetArg(&args[n++], Pt_ARG_TEXT_STRING, pSS->getValue(XAP_STRING_ID_DLG_OK), 0);
+PtSetArg(&args[n++], Pt_ARG_TEXT_STRING, _(XAP,DLG_OK), 0);
 	PtSetArg(&args[n++], Pt_ARG_WIDTH, ABI_DEFAULT_BUTTON_WIDTH, 0);
 	buttonOK = PtCreateWidget(PtButton, hgroup, n, args);
 	PtAddCallback(buttonOK, Pt_CB_ACTIVATE, s_modify_ok_clicked, this);
@@ -1048,7 +971,7 @@ PtWidget_t *  AP_QNXDialog_Styles::_constructModifyDialog(void)
 	_constructFormatList(FormatMenu);
 
 	n = 0;
-	PtSetArg(&args[n++], Pt_ARG_TEXT_STRING, pSS->getValue(AP_STRING_ID_DLG_Styles_ModifyShortCut), 0);
+PtSetArg(&args[n++], Pt_ARG_TEXT_STRING, _(AP,DLG_Styles_ModifyShortCut), 0);
 	PtSetArg(&args[n++], Pt_ARG_WIDTH, ABI_DEFAULT_BUTTON_WIDTH, 0);
 	shortCutButton = PtCreateWidget(PtButton, hgroup, n, args);
 	//PtAddCallback(shortCutButton, Pt_CB_ACTIVATE, s_modify_ok_clicked, this);
@@ -1077,27 +1000,26 @@ PtWidget_t *  AP_QNXDialog_Styles::_constructModifyDialog(void)
 
 void  AP_QNXDialog_Styles::_constructFormatList(PtWidget_t * FormatMenu)
 {
-	PtWidget_t *FormatMenu_menu;
 	const XAP_StringSet * pSS = m_pApp->getStringSet();
 	
 	const char *item;
 
-	item = pSS->getValue(AP_STRING_ID_DLG_Styles_ModifyFormat);
+item = pSS->getValueUTF8(AP_STRING_ID_DLG_Styles_ModifyFormat).utf8_str();
 	PtListAddItems(FormatMenu, &item, 1, 0);
 
-	item = pSS->getValue(AP_STRING_ID_DLG_Styles_ModifyParagraph);
+item = pSS->getValueUTF8(AP_STRING_ID_DLG_Styles_ModifyParagraph).utf8_str();
 	PtListAddItems(FormatMenu, &item, 1, 0);
 
-	item = pSS->getValue(AP_STRING_ID_DLG_Styles_ModifyFont);
+item = pSS->getValueUTF8(AP_STRING_ID_DLG_Styles_ModifyFont).utf8_str();
 	PtListAddItems(FormatMenu, &item, 1, 0);
 
-	item = pSS->getValue(AP_STRING_ID_DLG_Styles_ModifyTabs);
+item = pSS->getValueUTF8(AP_STRING_ID_DLG_Styles_ModifyTabs).utf8_str();
 	PtListAddItems(FormatMenu, &item, 1, 0);
 
-	item = pSS->getValue(AP_STRING_ID_DLG_Styles_ModifyNumbering);
+item = pSS->getValueUTF8(AP_STRING_ID_DLG_Styles_ModifyNumbering).utf8_str();
 	PtListAddItems(FormatMenu, &item, 1, 0);
 
-	item = pSS->getValue(AP_STRING_ID_DLG_Styles_ModifyLanguage);
+item = pSS->getValueUTF8(AP_STRING_ID_DLG_Styles_ModifyLanguage).utf8_str();
 	PtListAddItems(FormatMenu, &item, 1, 0);
 
 	PtAddCallback(FormatMenu, Pt_CB_SELECTION, s_modify_format, this);
@@ -1170,17 +1092,17 @@ void AP_QNXDialog_Styles::new_styleName(void)
 	char * psz = NULL;
 	psz = _combo_or_text_entry(m_wStyleNameEntry, NULL);
 
-	if(psz && strcmp(psz,pSS->getValue(AP_STRING_ID_DLG_Styles_DefNone))== 0)
+if(psz && strcmp(psz,pSS->getValueUTF8(AP_STRING_ID_DLG_Styles_DefNone ).utf8_str())== 0)
 	{
 			// TODO: do a real error dialog
-		sprintf(message,"%s%s%s",pSS->getValue(AP_STRING_ID_DLG_Styles_ErrNotTitle1),psz,pSS->getValue(AP_STRING_ID_DLG_Styles_ErrNotTitle2));
+sprintf(message,"%s%s%s",pSS->getValueUTF8(AP_STRING_ID_DLG_Styles_ErrNotTitle1).utf8_str(),psz,pSS->getValue(AP_STRING_ID_DLG_Styles_ErrNotTitle2));
 		//messageBoxOK((const char *) message);
 		return;
 	}
-	if(psz && strcmp(psz,pSS->getValue(AP_STRING_ID_DLG_Styles_DefCurrent))== 0)
+if(psz && strcmp(psz,pSS->getValueUTF8(AP_STRING_ID_DLG_Styles_DefCurrent).utf8_str())== 0)
 	{
 			// TODO: do a real error dialog
-		sprintf(message,"%s%s%s",pSS->getValue(AP_STRING_ID_DLG_Styles_ErrNotTitle1),psz,pSS->getValue(AP_STRING_ID_DLG_Styles_ErrNotTitle2));
+sprintf(message,"%s%s%s",pSS->getValueUTF8(AP_STRING_ID_DLG_Styles_ErrNotTitle1).utf8_str(),psz,pSS->getValueUTF8(AP_STRING_ID_DLG_Styles_ErrNotTitle2).utf8_str());
 		//messageBoxOK((const char *) message);
 		return;
 	}
@@ -1203,23 +1125,6 @@ void AP_QNXDialog_Styles::event_RemoveProperty(void)
 
 void AP_QNXDialog_Styles::rebuildDeleteProps(void)
 {
-#if 0
-	GtkCombo* delCombo = GTK_COMBO(m_wDeletePropCombo);
-	GtkList * oldList = GTK_LIST(delCombo->list);
-	if(oldList != NULL)
-	{
-		gtk_list_clear_items(oldList,0,-1);
-	}
-	UT_sint32 count = m_vecAllProps.getItemCount();
-	UT_sint32 i= 0;
-	for(i=0; i< count; i+=2)
-	{
-		gchar * sz = (gchar *) m_vecAllProps.getNthItem(i);
-		PtWidget_t * li = gtk_list_item_new_with_label(sz);
-		gtk_widget_show(li);
-		gtk_container_add(GTK_CONTAINER(delCombo->list),li);
-	}
-#endif
 }
 
 /*!
@@ -1261,7 +1166,7 @@ void AP_QNXDialog_Styles::event_styleType(void)
 
 	snprintf((char *) m_styleType,40,"%s",psz);
 	const XML_Char * pszSt = "P";
-	if(strstr(m_styleType, pSS->getValue(AP_STRING_ID_DLG_Styles_ModifyCharacter)) != 0)
+if(strstr(m_styleType, pSS->getValueUTF8(AP_STRING_ID_DLG_Styles_ModifyCharacter ).utf8_str()) != 0)
 		pszSt = "C";
 	addOrReplaceVecAttribs("type",pszSt);
 }
@@ -1288,12 +1193,10 @@ void  AP_QNXDialog_Styles::modifyRunModal(void)
 	PtWidget_t *mainWindow;
 
 	// To center the dialog, we need the frame of its parent.
-	XAP_QNXFrame * pQNXFrame = (XAP_QNXFrame *)getFrame();
-	UT_ASSERT(pQNXFrame);
-	
-	// Get the Window of the parent frame
-	PtWidget_t * parentWindow = pQNXFrame->getTopLevelWindow();
+	XAP_QNXFrameImpl * pQNXFrameImpl = (XAP_QNXFrameImpl*)getFrame()->getFrameImpl();
+	PtWidget_t *parentWindow =	pQNXFrameImpl->getTopLevelWindow();	
 	UT_ASSERT(parentWindow);
+	
 	PtSetParentWidget(parentWindow);
 
 	m_wModifyDialog =
@@ -1372,67 +1275,6 @@ void AP_QNXDialog_Styles::event_ModifyPreviewExposed(void)
 
 void AP_QNXDialog_Styles::event_ModifyClicked(void)
 {
-#if 0
-	PD_Style * pStyle = NULL;
-	const char * szCurrentStyle = getCurrentStyle ();
-	
-	if(szCurrentStyle)
-		getDoc()->getStyle(szCurrentStyle, &pStyle);
-	
-	if (!pStyle)
-	{
-		// TODO: error message - nothing selected
-		return;
-	}
-
-	if (!pStyle->isUserDefined ())
-	{
-		// can't change builtin, error message
-		const XAP_StringSet * pSS = m_pApp->getStringSet();
-		const XML_Char * msg = pSS->getValue (AP_STRING_ID_DLG_Styles_ErrStyleBuiltin);
-		
-		getFrame()->showMessageBox ((const char *)msg,
-									XAP_Dialog_MessageBox::b_O,
-									XAP_Dialog_MessageBox::a_OK);
-		return;
-	}
-	
-	
-#ifndef HAVE_GNOME
-//
-// Hide the old window
-//
-    gtk_widget_hide(m_windowMain);
-#endif
-//
-// fill the data structures needed for the Modify dialog
-//
-	setIsNew(false);
-	
-	modifyRunModal();
-	if(m_answer == AP_Dialog_Styles::a_OK)
-	{
-		applyModifiedStyleToDoc();
-		getDoc()->updateDocForStyleChange(getCurrentStyle(),true);
-		getDoc()->signalListeners(PD_SIGNAL_UPDATE_LAYOUT);
-	}
-	else
-	{
-//
-// Do other stuff
-//
-	}
-//  
-// Restore the values in the main dialog
-//
-	
-#ifndef HAVE_GNOME
-//
-// Reveal main window again
-//
-	gtk_widget_show( m_windowMain);
-#endif
-#endif
 }
 
 void  AP_QNXDialog_Styles::setModifyDescription( const char * desc)
@@ -1460,21 +1302,14 @@ bool  AP_QNXDialog_Styles::_populateModify(void)
 		if(!szCurrentStyle)
 		{
 			// TODO: change me to use a real messagebox
-			//messageBoxOK( pSS->getValue(AP_STRING_ID_DLG_Styles_ErrNoStyle));
+//messageBoxOK( pSS->getValueUTF8(AP_STRING_ID_DLG_Styles_ErrNoStyle ).utf8_str();
 			m_answer = AP_Dialog_Styles::a_CANCEL;
 			return false;
 		}
 		_combo_or_text_entry(m_wStyleNameEntry, getCurrentStyle());
-/*
-		gtk_entry_set_text (GTK_ENTRY(m_wStyleNameEntry), getCurrentStyle());
-		gtk_entry_set_editable( GTK_ENTRY(m_wStyleNameEntry),FALSE );
-*/
 	}
 	else
 	{
-/*
-		gtk_entry_set_editable( GTK_ENTRY(m_wStyleNameEntry),TRUE );
-*/
 	}
 
 	//
@@ -1493,7 +1328,7 @@ bool  AP_QNXDialog_Styles::_populateModify(void)
 		if(!pStyle)
 		{
 			// TODO: do a real error dialog
-			//messageBoxOK( pSS->getValue(AP_STRING_ID_DLG_Styles_ErrStyleNot));
+//messageBoxOK( pSS->getValueUTF8(AP_STRING_ID_DLG_Styles_ErrStyleNot ).utf8_str();
 			m_answer = AP_Dialog_Styles::a_CANCEL;
 			return false;
 		}
@@ -1531,16 +1366,16 @@ bool  AP_QNXDialog_Styles::_populateModify(void)
 		PtListAddItems(m_wFollowingEntry, &name, 1, 0);
 	}
 
-	const char *item = pSS->getValue(AP_STRING_ID_DLG_Styles_DefCurrent);
+const char *item = pSS->getValueUTF8(AP_STRING_ID_DLG_Styles_DefCurrent).utf8_str();
 	_combo_or_text_entry(m_wFollowingEntry, item); 
 
-	item = pSS->getValue(AP_STRING_ID_DLG_Styles_DefNone);
+item = pSS->getValueUTF8(AP_STRING_ID_DLG_Styles_DefNone).utf8_str();
 	_combo_or_text_entry(m_wBasedOnEntry, item); 
 
-	item = pSS->getValue(AP_STRING_ID_DLG_Styles_ModifyParagraph);
+item = pSS->getValueUTF8(AP_STRING_ID_DLG_Styles_ModifyParagraph).utf8_str();
 	_combo_or_text_entry(m_wStyleTypeEntry, item); 
 
-	item = pSS->getValue(AP_STRING_ID_DLG_Styles_ModifyCharacter);
+item = pSS->getValueUTF8(AP_STRING_ID_DLG_Styles_ModifyCharacter).utf8_str();
 	_combo_or_text_entry(m_wStyleTypeEntry, item); 
  
 	/*
@@ -1557,26 +1392,26 @@ bool  AP_QNXDialog_Styles::_populateModify(void)
 		if(pBasedOnStyle != NULL)
 			_combo_or_text_entry(m_wBasedOnEntry, szBasedOn);
 		else
-			_combo_or_text_entry(m_wBasedOnEntry, pSS->getValue(AP_STRING_ID_DLG_Styles_DefNone));
+	_combo_or_text_entry(m_wBasedOnEntry, pSS->getValueUTF8(AP_STRING_ID_DLG_Styles_DefNone ).utf8_str());
 
 		if(pFollowedByStyle != NULL)
 			_combo_or_text_entry(m_wFollowingEntry, szFollowedBy);
 		else
-			_combo_or_text_entry(m_wFollowingEntry, pSS->getValue(AP_STRING_ID_DLG_Styles_DefCurrent));
+_combo_or_text_entry(m_wFollowingEntry, pSS->getValueUTF8(AP_STRING_ID_DLG_Styles_DefCurrent ).utf8_str());
 
 		if(strstr(getAttsVal("type"),"P") != 0)
-			_combo_or_text_entry(m_wStyleTypeEntry, pSS->getValue(AP_STRING_ID_DLG_Styles_ModifyParagraph));
+_combo_or_text_entry(m_wStyleTypeEntry, pSS->getValueUTF8(AP_STRING_ID_DLG_Styles_ModifyParagraph ).utf8_str());
 		else
-			_combo_or_text_entry(m_wStyleTypeEntry, pSS->getValue(AP_STRING_ID_DLG_Styles_ModifyCharacter));
+_combo_or_text_entry(m_wStyleTypeEntry, pSS->getValueUTF8(AP_STRING_ID_DLG_Styles_ModifyCharacter ).utf8_str());
 	}
 	else
 	{
 		//
 		// Hardwire defaults for "new"
 		//
-		_combo_or_text_entry(m_wBasedOnEntry, pSS->getValue(AP_STRING_ID_DLG_Styles_DefNone));
-		_combo_or_text_entry(m_wFollowingEntry, pSS->getValue(AP_STRING_ID_DLG_Styles_DefCurrent));
-		_combo_or_text_entry(m_wStyleTypeEntry, pSS->getValue(AP_STRING_ID_DLG_Styles_ModifyParagraph));
+_combo_or_text_entry(m_wBasedOnEntry, pSS->getValueUTF8(AP_STRING_ID_DLG_Styles_DefNone ).utf8_str());
+_combo_or_text_entry(m_wFollowingEntry, pSS->getValueUTF8(AP_STRING_ID_DLG_Styles_DefCurrent ).utf8_str());
+_combo_or_text_entry(m_wStyleTypeEntry, pSS->getValueUTF8(AP_STRING_ID_DLG_Styles_ModifyParagraph ).utf8_str());
 	}
 
 	//
@@ -1608,137 +1443,23 @@ bool  AP_QNXDialog_Styles::_populateModify(void)
 
 void   AP_QNXDialog_Styles::event_ModifyParagraph()
 {
-#if 0
-#ifndef HAVE_GNOME
-//
-// Hide this window
-//
-    gtk_widget_hide(m_wModifyDialog);
-#endif
-
-//
-// Can do all this in XP land.
-//
-	ModifyParagraph();
-	rebuildDeleteProps();
-#ifndef HAVE_GNOME
-//
-// Restore this window
-//
-    gtk_widget_show(m_wModifyDialog);
-#endif
-
-//
-// This applies the changes to current style and displays them
-//
-	updateCurrentStyle();
-#endif
 }
 
 void   AP_QNXDialog_Styles::event_ModifyFont()
 {
-#if 0
-#ifndef HAVE_GNOME
-//
-// Hide this window
-//
-    gtk_widget_hide(m_wModifyDialog);
-#endif
-
-//
-// Can do all this in XP land.
-//
-	ModifyFont();
-	rebuildDeleteProps();
-#ifndef HAVE_GNOME
-//
-// Restore this window
-//
-    gtk_widget_show(m_wModifyDialog);
-#endif
-
-//
-// This applies the changes to current style and displays them
-//
-	updateCurrentStyle();
-#endif
 }
 
 void AP_QNXDialog_Styles::event_ModifyLanguage()
 {
-#if 0
-#ifndef HAVE_GNOME
-	gtk_widget_hide (m_wModifyDialog);
-#endif
-
-	ModifyLang();
-	rebuildDeleteProps();
-#ifndef HAVE_GNOME
-	gtk_widget_show (m_wModifyDialog);
-#endif
-
-	updateCurrentStyle();
-#endif
 }
 
 void   AP_QNXDialog_Styles::event_ModifyNumbering()
 {
-#if 0
-#ifndef HAVE_GNOME
-//
-// Hide this window
-//
-    gtk_widget_hide(m_wModifyDialog);
-#endif
-
-//
-// Can do all this in XP land.
-//
-	ModifyLists();
-	rebuildDeleteProps();
-#ifndef HAVE_GNOME
-//
-// Restore this window
-//
-    gtk_widget_show(m_wModifyDialog);
-#endif
-
-//
-// This applies the changes to current style and displays them
-//
-	updateCurrentStyle();
-
-#endif
 }
 
 
 void   AP_QNXDialog_Styles::event_ModifyTabs()
 {
-#if 0
-#ifndef HAVE_GNOME
-//
-// Hide this window
-//
-    gtk_widget_hide(m_wModifyDialog);
-#endif
-
-//
-// Can do all this in XP land.
-//
-	ModifyTabs();
-	rebuildDeleteProps();
-#ifndef HAVE_GNOME
-//
-// Restore this window
-//
-    gtk_widget_show(m_wModifyDialog);
-#endif
-
-//
-// This applies the changes to current style and displays them
-//
-	updateCurrentStyle();
-#endif
 }
 
 bool  AP_QNXDialog_Styles::isModifySignalBlocked(void) const
